![Banner](https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcQeIN7JV_CPRq72K4Yfsn36TGr0v9G2By8rTg&usqp=CAU)

# Models

This folder contains models that are done or require further improvements.

### Best Model

#### <img src="https://pbs.twimg.com/profile_images/1415398873552543744/BrvPGbfQ_400x400.png"  height="15"/> ForeFront.ai

This is the best model for the job, fast and with GPT-4 available for use. With conversation and history chat systems, it is the most advanced.

## Purpose

This helps to keep the repository organized and makes it easier for users to find working models.

## Contributing

If you want to contribute to one of these models, feel free. Don't forget to specify what type of contribution you are going to make, to fix a bug, add a new feature or improve the code's architecture. Try to code in the format of the other templates for better work and simplicity in use.



## Disclaimer

If you want to use a model in this folder, don't say you made it unless you contributed to one of the models used. To be recognized for work you didn't do is really sad :(.






